@@ -20,6 +20,7 @@ import (
 	"fmt"
 
 	"helm.sh/helm/v3/pkg/action"
+	"helm.sh/helm/v3/pkg/chart"
 	"helm.sh/helm/v3/pkg/chart/loader"
 	"helm.sh/helm/v3/pkg/kube"
 	helmrelease "helm.sh/helm/v3/pkg/release"
@@ -30,8 +31,8 @@ import (
 	v1 "k8s.io/client-go/kubernetes/typed/core/v1"
 	crmanager "sigs.k8s.io/controller-runtime/pkg/manager"
 
-	appv1 "github.com/stolostron/multicloud-operators-subscription-release/pkg/apis/apps/v1"
-	"github.com/stolostron/multicloud-operators-subscription-release/pkg/client"
+	appv1 "github.com/open-cluster-management/multicloud-operators-subscription-release/pkg/apis/apps/v1"
+	"github.com/open-cluster-management/multicloud-operators-subscription-release/pkg/client"
 )
 
 // ManagerFactory creates Managers that are specific to custom resources. It is
@@ -74,14 +75,20 @@ func (f managerFactory) NewManager(cr *unstructured.Unstructured, overrideValues
 		return nil, fmt.Errorf("failed to inject owner references: %w", err)
 	}
 
-	crChart, err := loader.LoadDir(f.chartDir)
-	if err != nil {
-		return nil, fmt.Errorf("failed to load chart dir: %w", err)
-	}
+	releaseName := cr.GetName()
 
-	releaseName, err := getReleaseName(storageBackend, crChart.Name(), cr)
-	if err != nil {
-		return nil, fmt.Errorf("failed to get helm release name: %w", err)
+	var crChart *chart.Chart
+
+	if cr.GetDeletionTimestamp() == nil {
+		crChart, err = loader.LoadDir(f.chartDir)
+		if err != nil {
+			return nil, fmt.Errorf("failed to load chart dir, most likely the given chart name is incorrect: %w", err)
+		}
+
+		releaseName, err = getReleaseName(storageBackend, crChart.Name(), cr)
+		if err != nil {
+			return nil, fmt.Errorf("failed to get helm release name: %w", err)
+		}
 	}
 
 	crValues, ok := cr.Object["spec"].(map[string]interface{})
